SDQC
====

This Python library allows checking the quality of the input data of [System Dynamics](http://en.wikipedia.org/wiki/System_dynamics) models developed in Vensim. It uses [PySD](https://github.com/JamesPHoughton/pysd) library to parse the model and load the input data from spreadsheet files.

### Requirements
- Python 3.7+
- PySD 2.1+

### Resources
See the [project documentation](http://sdqc.readthedocs.org/) for information about:

- [Installation](http://sdqc.readthedocs.org/en/latest/installation.html)
- [Usage](http://sdqc.readthedocs.org/en/latest/usage.html)
- [Data quality reporting](http://sdqc.readthedocs.org/en/latest/report_configuration.html)

### Authority and acknowledgmentes
This library was developed by [@eneko.martin.martinez](https://gitlab.com/eneko.martin.martinez) at [Centre de Recerca Ecològica i Aplicacions Forestals (CREAF)](http://www.creaf.cat/).

This project has received funding from the European Union’s Horizon 2020
research and innovation programme under grant agreement No. 821105.
